@@ -256,7 +256,7 @@ def setup_hyp(experiment=None, data_yaml_path=None, config_path= None,  params={
 
     opt.resume = False
     opt.bucket = ''
-    opt.device = 'cuda:0' if torch.cuda.is_available() else 'cpu'
+    opt.device = 'cuda:0' if torch.cuda.is_available() and torch.cuda.device_count() >= 0 else 'cpu'
     opt.local_rank = -1 
     opt.log_imgs = 4
     opt.workers = 4
@@ -279,7 +279,7 @@ def setup_hyp(experiment=None, data_yaml_path=None, config_path= None,  params={
     with open(opt.hyp) as f:
         hyp = yaml.load(f, Loader=yaml.SafeLoader)  # load hyps
 
-    device = 'cuda:0' if torch.cuda.is_available() else 'cpu'
+    device = torch.device(opt.device)
     return hyp, opt, device
 
 def find_final_run(YOLODIR, exp_name):
@@ -352,10 +352,15 @@ def send_run_to_picsellia(experiment, YOLODIR):
     final_run_path = find_final_run(YOLODIR, experiment.name)
     best_weigths, last_weights, hyp_yaml = get_weights_and_config(final_run_path)
 
+    device = torch.device('cpu')
+    model = torch.load(best_weigths, map_location=device)['model'].float()
+    torch.onnx.export(model, torch.zeros((1, 3, 640, 640)), 'model.onnx', opset_version=12)
+
     if best_weigths is not None:
         experiment.store('best-weights', best_weigths)
     if last_weights is not None:
         experiment.store('last-weights', last_weights)
+    experiment.store('model-latest', 'model.onnx')
     if hyp_yaml is not None:
         experiment.store('checkpoint-data-latest', hyp_yaml)
     for curve in get_metrics_curves(final_run_path):
