@@ -7,7 +7,7 @@ import time
 from copy import deepcopy
 from pathlib import Path
 from threading import Thread
-
+from picsellia.types.enums import LogType
 import numpy as np
 import torch.distributed as dist
 import torch.nn as nn
@@ -188,7 +188,6 @@ def train(hyp, opt, device, tb_writer=None, wandb=None, pxl=None):
         logger.info('Using SyncBatchNorm()')
 
     # Trainloader
-    print(os.path.isdir(train_path))
     dataloader, dataset = create_dataloader(train_path, imgsz, batch_size, gs, opt,
                                             hyp=hyp, augment=True, cache=opt.cache_images, rect=opt.rect, rank=rank,
                                             world_size=opt.world_size, workers=opt.workers,
@@ -385,14 +384,15 @@ def train(hyp, opt, device, tb_writer=None, wandb=None, pxl=None):
                     if tag in verified_tags:
                         try:
                             name = str(tag).replace('/', '_')
-                            pxl.log(name=name, type='line', data=[x])
+                            pxl.log(name=name, type=LogType.LINE, data=float(x))
                         except Exception as e:
                             logger.info(str(e))
                             try:
                                 #name = tag.cpu()
                                 name = str(tag).replace('/', '_')
-                                pxl.log(name=name, type='line', data=x.cpu().numpy())
-                            except:
+                                pxl.log(name=name, type=LogType.LINE, data=float(x))
+                            except Exception as e:
+                                print(e)
                                 print(tag, "can't be uploaded")
             # Update best mAP
             fi = fitness(np.array(results).reshape(1, -1))  # weighted combination of [P, R, mAP@.5, mAP@.5-.95]
@@ -459,7 +459,7 @@ def train(hyp, opt, device, tb_writer=None, wandb=None, pxl=None):
 
     wandb.run.finish() if wandb and wandb.run else None
     torch.cuda.empty_cache()
-    return results
+    return model
 
 
 def generate_opt(opt):
